"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint no-console: 0 */
const core_1 = require("@curveball/core");
const main_mw_1 = require("./main-mw");
const accesslog_1 = require("@curveball/accesslog");
const database_1 = require("./database");
const server_settings_1 = require("./server-settings");
// eslint-disable-next-line @typescript-eslint/no-var-requires
require('dotenv').config();
// eslint-disable-next-line @typescript-eslint/no-var-requires
const pkgInfo = require('../package.json');
console.info('⚾ %s %s', pkgInfo.name, pkgInfo.version);
const port = process.env.PORT ? parseInt(process.env.PORT, 10) : 8531;
if (!process.env.PUBLIC_URI) {
    process.env.PUBLIC_URI = 'http://localhost:' + port + '/';
    console.log('PUBLIC_URI environment variable was not set, defaulting to http://localhost:' + port + '/');
}
(async () => {
    await (0, database_1.init)();
    await (0, server_settings_1.load)();
    const app = new core_1.Application();
    app.use((0, accesslog_1.default)({
        blacklist: [],
    }));
    app.use((0, main_mw_1.default)());
    app.listen(port);
    console.log('Running on \x1b[31m%s\x1b[0m', app.origin + '/');
})().catch((err) => {
    console.error('Could not start a12n-server');
    console.error(err);
    process.exit(2);
});
//# sourceMappingURL=app.js.map