"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const privilegeService = require("../../privilege/service");
const hal = require("../formats/hal");
const principalService = require("../../principal/service");
class UserCollectionController extends controller_1.default {
    async get(ctx) {
        const apps = await principalService.findAll('app');
        ctx.response.body = hal.collection(apps);
    }
    async post(ctx) {
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege may app new apps');
        }
        ctx.request.validate('https://curveballjs.org/schemas/a12nserver/new-principal.json');
        if (ctx.request.body.type !== 'app') {
            throw new http_errors_1.BadRequest('You may only create principals with type "app" at this endpoint');
        }
        const identity = ctx.request.links.get('me')?.href;
        if (!identity) {
            throw new http_errors_1.UnprocessableEntity('You must specify a link with rel "me", either via a HAL link or HTTP Link header');
        }
        try {
            await principalService.findByIdentity(identity);
            throw new http_errors_1.Conflict('Principal already exists');
        }
        catch (err) {
            if (!(err instanceof http_errors_1.NotFound)) {
                throw err;
            }
        }
        const app = await principalService.save({
            identity,
            nickname: ctx.request.body.nickname,
            type: 'app',
            active: ctx.request.body.active,
            createdAt: new Date(),
            modifiedAt: new Date(),
        });
        ctx.response.status = 201;
        ctx.response.headers.set('Location', app.href);
    }
}
exports.default = new UserCollectionController();
//# sourceMappingURL=collection.js.map