"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.uuidUrn = exports.generatePublicId = exports.generateSecretToken = void 0;
const crypto = require("node:crypto");
/**
 * Centralized place for all crypto-related functions
 */
/**
 * Returns a secret, opaque token.
 *
 * The token will use the characters from the base64url character list, which
 * is url-safe.
 */
function generateSecretToken() {
    return generateUrlSafeString(32);
}
exports.generateSecretToken = generateSecretToken;
/**
 * Generates an id
 *
 * The id is not meant to be secret, but is meant to be not numerable, making it
 * hard to guess (for example) how many users exist.
 */
function generatePublicId() {
    return generateUrlSafeString(8);
}
exports.generatePublicId = generatePublicId;
/**
 * Generates a UUID urn
 */
function uuidUrn() {
    return `urn:uuid:${crypto.randomUUID()}`;
}
exports.uuidUrn = uuidUrn;
function generateUrlSafeString(bytes) {
    return new Promise((res, rej) => {
        crypto.randomBytes(bytes, (err, buf) => {
            if (err) {
                rej(err);
                return;
            }
            const base64Url = buf.toString('base64')
                .replace(/\+/g, '-') // + -> -
                .replace(/\//g, '_') // / -> _
                .replace(/=/g, ''); // Strip =
            res(base64Url);
        });
    });
}
//# sourceMappingURL=crypto.js.map