"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const userService = require("../../principal/service");
const hal = require("../formats/hal");
const groupService = require("../service");
const http_errors_1 = require("@curveball/http-errors");
class GroupMemberCollectionController extends controller_1.default {
    async get(ctx) {
        const user = await userService.findById(+ctx.params.id, 'group');
        const members = await groupService.findMembers(user);
        ctx.response.body = hal.memberCollection(user, members);
    }
    /**
     * PUT replaces the member list.
     *
     * Members must be supplied with the 'item' link.
     */
    async put(ctx) {
        const group = await userService.findById(+ctx.params.id, 'group');
        if (!ctx.request.links.has('item')) {
            throw new http_errors_1.UnprocessableEntity('"item" link relationship not found');
        }
        const newMemberLinks = ctx.request.links.getMany('item');
        const newMembers = await Promise.all(newMemberLinks.map(async (link) => {
            try {
                return userService.findByHref(link.href);
            }
            catch (err) {
                throw new http_errors_1.Conflict(`User with href ${link.href} not found`);
            }
        }));
        await groupService.replaceMembers(group, newMembers);
        ctx.status = 204;
    }
    /**
     * The POST request here is a simpler rpc-like API to add a new member to the group..
     */
    async post(ctx) {
        const group = await userService.findById(+ctx.params.id, 'group');
        if (ctx.request.body.operation === undefined) {
            throw new http_errors_1.UnprocessableEntity('You must specify an "operation" property');
        }
        if (ctx.request.body.operation !== 'add-member') {
            throw new http_errors_1.UnprocessableEntity('"operation" must be set to "add-member"');
        }
        if (ctx.request.body.memberHref === undefined) {
            throw new http_errors_1.UnprocessableEntity('The "memberHref" property must be set, and must point to the member you are adding to the group.');
        }
        const newMemberHref = ctx.request.body.memberHref;
        let newMember;
        try {
            newMember = await userService.findByHref(newMemberHref);
        }
        catch (err) {
            if (err instanceof http_errors_1.NotFound) {
                throw new http_errors_1.Conflict(`User with href ${newMemberHref} not found`);
            }
            else {
                throw err;
            }
        }
        await groupService.addMember(group, newMember);
        ctx.status = 204;
    }
}
exports.default = new GroupMemberCollectionController();
//# sourceMappingURL=member-collection.js.map