"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const privilegeService = require("../../privilege/service");
const principalService = require("../../principal/service");
const html_1 = require("../formats/html");
const crypto_1 = require("../../crypto");
class CreateGroupController extends controller_1.default {
    async get(ctx) {
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege can create new users');
        }
        ctx.response.type = 'text/html';
        ctx.response.body = (0, html_1.createGroupForm)(ctx.query.msg, ctx.query.error);
    }
    async post(ctx) {
        ctx.request.validate('https://curveballjs.org/schemas/a12nserver/group-new-form.json');
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege can create new users');
        }
        const nickname = ctx.request.body.nickname;
        const newGroup = await principalService.save({
            type: 'group',
            nickname,
            active: true,
            identity: (0, crypto_1.uuidUrn)(),
            createdAt: new Date(),
            modifiedAt: new Date(),
        });
        ctx.response.status = 303;
        ctx.response.headers.set('Location', newGroup.href);
    }
}
exports.default = new CreateGroupController();
//# sourceMappingURL=new.js.map