"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.item = exports.collection = exports.memberCollection = void 0;
function memberCollection(group, members) {
    const hal = {
        _links: {
            self: {
                href: `${group.href}/member`,
                title: group.nickname + ' members'
            },
            item: members.map(member => ({
                href: member.href,
                title: member.nickname
            })),
        },
        total: members.length,
    };
    return hal;
}
exports.memberCollection = memberCollection;
function collection(groups) {
    const hal = {
        _links: {
            'self': { href: '/group' },
            'item': groups.map(group => ({
                href: group.href,
                title: group.nickname,
            })),
            'create-form': { href: '/group/new', title: 'Create New Group' },
        },
        total: groups.length,
    };
    return hal;
}
exports.collection = collection;
/**
 * Generate a HAL response for a specific group
 */
function item(group, privileges, isAdmin, groups, members) {
    const hal = {
        _links: {
            'self': { href: group.href, title: group.nickname },
            'me': { href: group.identity, title: group.nickname },
            'up': { href: '/group', title: 'List of groups' },
            'group': groups.map(group => ({
                href: group.href,
                title: group.nickname,
            })),
            'member': members.map(member => ({
                href: member.href,
                title: member.nickname
            })),
            'member-collection': {
                href: `${group.href}/member`,
                title: 'Group member',
                hints: {
                    status: 'deprecated'
                },
            }
        },
        nickname: group.nickname,
        active: group.active,
        createdAt: group.createdAt,
        modifiedAt: group.modifiedAt,
        type: group.type,
        privileges
    };
    if (isAdmin) {
        hal._links['privileges'] = {
            href: `${group.href}/edit/privileges`,
            title: 'Change privilege policy',
        };
        hal._templates = {
            'add-member': addMemberForm(group),
        };
        if (members.length > 0) {
            hal._templates['remove-member'] = removeMemberForm(group, members);
        }
    }
    return hal;
}
exports.item = item;
function addMemberForm(group) {
    return {
        method: 'PATCH',
        title: 'Add member',
        target: group.href,
        properties: [
            {
                type: 'hidden',
                name: 'operation',
                value: 'add-member',
            },
            {
                type: 'text',
                prompt: 'Member',
                name: 'memberHref',
            },
        ]
    };
}
function removeMemberForm(group, members) {
    return {
        method: 'PATCH',
        title: 'Remove member',
        target: group.href,
        properties: [
            {
                type: 'hidden',
                name: 'operation',
                value: 'remove-member',
            },
            {
                type: 'text',
                prompt: 'Member',
                name: 'memberHref',
                options: {
                    inline: members.map(member => ({
                        prompt: member.nickname,
                        value: member.href
                    }))
                },
            },
        ]
    };
}
//# sourceMappingURL=hal.js.map