"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findGroupsForPrincipal = exports.removeMember = exports.replaceMembers = exports.addMember = exports.findMembers = void 0;
const database_1 = require("../database");
const principalService = require("../principal/service");
/**
 * Finding group members
 */
async function findMembers(group) {
    const result = await (0, database_1.query)(`SELECT ${principalService.fieldNames.join(', ')} FROM principals INNER JOIN group_members ON principals.id = group_members.user_id WHERE group_id = ? ORDER BY nickname`, [group.id]);
    const models = [];
    for (const record of result) {
        const model = principalService.recordToModel(record);
        models.push(model);
    }
    return models;
}
exports.findMembers = findMembers;
async function addMember(group, user) {
    const query = 'INSERT INTO group_members SET group_id = ?, user_id = ?';
    await database_1.default.raw(query, [group.id, user.id]);
}
exports.addMember = addMember;
async function replaceMembers(group, users) {
    await database_1.default.transaction(async (trx) => {
        await trx.raw('DELETE FROM group_members WHERE group_id = ?', [group.id]);
        for (const user of users) {
            await trx.raw('INSERT INTO group_members SET group_id = ?, user_id = ?', [group.id, user.id]);
        }
        await trx.commit();
    });
}
exports.replaceMembers = replaceMembers;
async function removeMember(group, user) {
    const query = 'DELETE FROM group_members WHERE group_id = ? AND user_id = ?';
    await database_1.default.raw(query, [group.id, user.id]);
}
exports.removeMember = removeMember;
/**
 * Finding group members
 */
async function findGroupsForPrincipal(principal) {
    const result = await (0, database_1.query)(`SELECT ${principalService.fieldNames.join(', ')} FROM principals INNER JOIN group_members ON principals.id = group_members.group_id WHERE user_id = ?`, [principal.id]);
    const models = [];
    for (const record of result) {
        const model = principalService.recordToModel(record);
        models.push(model);
    }
    return models;
}
exports.findGroupsForPrincipal = findGroupsForPrincipal;
//# sourceMappingURL=service.js.map