"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const http_errors_2 = require("@curveball/http-errors");
const oauth2Service = require("../oauth2/service");
const privilegeService = require("../privilege/service");
const json_1 = require("./formats/json");
/**
 * The /introspect endpoint allows a client to get more information
 * about an issued access or refresh token.
 *
 * This is an implementation of RFC7662: OAuth 2.0 Token Introspection
 */
class IntrospectionController extends controller_1.default {
    async post(ctx) {
        if (!ctx.request.is('application/x-www-form-urlencoded')) {
            throw new http_errors_1.UnsupportedMediaType('This endpoint only supports application/x-www-form-urlencoded');
        }
        if (!('token' in ctx.request.body)) {
            throw new http_errors_1.UnprocessableEntity('The "token" parameter must be set');
        }
        const token = ctx.request.body.token;
        const tokenTypeHint = ctx.request.body.token_type_hint || null;
        ctx.response.type = 'application/json';
        let foundToken = null;
        let foundTokenType;
        if (tokenTypeHint === null || tokenTypeHint === 'access_token') {
            try {
                foundToken = await oauth2Service.getTokenByAccessToken(token);
                foundTokenType = 'accessToken';
            }
            catch (err) {
                if (!(err instanceof http_errors_2.NotFound)) {
                    // Rethrowing everything except 'not found'
                    throw err;
                }
            }
        }
        if (tokenTypeHint === null || tokenTypeHint === 'refresh_token') {
            try {
                foundToken = await oauth2Service.getTokenByRefreshToken(token);
                foundTokenType = 'refreshToken';
            }
            catch (err) {
                if (!(err instanceof http_errors_2.NotFound)) {
                    // Rethrowing everything except 'not found'
                    throw err;
                }
            }
        }
        if (foundToken) {
            const privileges = await privilegeService.getPrivilegesForPrincipal(foundToken.user);
            switch (foundTokenType) {
                case 'accessToken':
                    ctx.response.body = (0, json_1.accessToken)(foundToken, privileges);
                    break;
                case 'refreshToken':
                    ctx.response.body = (0, json_1.refreshToken)(foundToken, privileges);
                    break;
            }
            return;
        }
        ctx.response.body = (0, json_1.inactive)();
    }
}
exports.default = new IntrospectionController();
//# sourceMappingURL=controller.js.map