"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findByUser = exports.addLogEntry = void 0;
const database_1 = require("../database");
const geoip = require("geoip-lite");
async function log(eventType, arg1, arg2, arg3) {
    if (isContext(arg1)) {
        await addLogEntry(eventType, arg1.ip() ?? '', arg1.session.user?.id ?? null, arg1.request.headers.get('User-Agent'));
    }
    else {
        await addLogEntry(eventType, arg1 ?? '', arg2, arg3 ?? '');
    }
}
exports.default = log;
async function addLogEntry(eventType, ip, userId, userAgent) {
    await (0, database_1.default)('user_log').insert({
        user_id: userId,
        time: Math.floor(Date.now() / 1000),
        event_type: eventType,
        ip: ip,
        user_agent: userAgent,
        country: ip ? getCountryByIp(ip) : null,
    });
}
exports.addLogEntry = addLogEntry;
async function findByUser(user) {
    const result = await (0, database_1.default)('user_log')
        .select('*')
        .where({ user_id: user.id });
    return result.map((row) => {
        return {
            time: new Date(row.time * 1000),
            ip: row.ip,
            eventType: row.event_type,
            userAgent: row.user_agent,
            country: row.country
        };
    });
}
exports.findByUser = findByUser;
function isContext(ctx) {
    return ctx.ip !== undefined;
}
function getCountryByIp(ip) {
    return geoip.lookup(ip)?.country || null;
}
//# sourceMappingURL=service.js.map