"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const bodyparser_1 = require("@curveball/bodyparser");
const browser_1 = require("@curveball/browser");
const cors_1 = require("@curveball/cors");
const links_1 = require("@curveball/links");
const problem_1 = require("@curveball/problem");
const session_1 = require("@curveball/session");
const validator_1 = require("@curveball/validator");
const session_redis_1 = require("@curveball/session-redis");
const core_1 = require("@curveball/core");
const login_1 = require("./middleware/login");
const routes_1 = require("./routes");
const server_settings_1 = require("./server-settings");
const path_1 = require("path");
/**
 * The 'main middleware'.
 *
 * Most of the application is expressed as a single middleware. This could
 * potentially allow a12nserver to be embedded in another curveball
 * application.
 */
function default_1() {
    if (process.env.PUBLIC_URI === undefined) {
        throw new Error('PUBLIC_URI environment variable must be set.');
    }
    const middlewares = [];
    const corsAllowOrigin = (0, server_settings_1.getSetting)('cors.allowOrigin');
    if (corsAllowOrigin) {
        middlewares.push((0, cors_1.default)({
            allowOrigin: corsAllowOrigin
        }));
    }
    middlewares.push((0, browser_1.default)({
        title: 'a12n-server',
        stylesheets: [
            '/assets/extra.css'
        ],
    }), (0, problem_1.default)(), (0, session_1.default)({
        store: process.env.REDIS_HOST ? new session_redis_1.RedisStore({
            prefix: 'A12N-session',
            clientOptions: {
                port: process.env.REDIS_PORT ? parseInt(process.env.REDIS_PORT, 10) : 6379,
                host: process.env.REDIS_HOST ? process.env.REDIS_HOST : '127.0.0.1',
            },
        }) : 'memory',
        cookieName: 'A12N',
        expiry: 60 * 60 * 24 * 7,
    }), (0, login_1.default)(), (0, bodyparser_1.default)(), (0, links_1.default)(), (0, validator_1.default)({
        schemaPath: (0, path_1.join)(__dirname, '../schemas'),
        noLink: true,
    }), ...routes_1.default);
    /**
     * This middleware contains all the a12n-server functionality.
     */
    return (ctx, next) => {
        return (0, core_1.invokeMiddlewares)(ctx, [...middlewares, next]);
    };
}
exports.default = default_1;
//# sourceMappingURL=main-mw.js.map