"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const otplib_1 = require("otplib");
const QRCode = require("qrcode");
const service_1 = require("../service");
const html_1 = require("../formats/html");
const server_settings_1 = require("../../../server-settings");
class TOTPRegisterController extends controller_1.default {
    async get(ctx) {
        const user = ctx.session.registerUser;
        if (!user) {
            return ctx.redirect(303, '/login');
        }
        const secret = ctx.session.totpSecret ? ctx.session.totpSecret : (0, service_1.generateSecret)();
        ctx.session.totpSecret = secret;
        const otpauth = otplib_1.authenticator.keyuri(user.nickname, (0, server_settings_1.getSetting)('totp.serviceName'), secret);
        const qrCode = await QRCode.toDataURL(otpauth);
        ctx.response.type = 'text/html';
        ctx.response.body = (0, html_1.registrationForm)(ctx.query.msg, ctx.query.error, secret, qrCode);
    }
    async post(ctx) {
        const user = ctx.session.registerUser;
        if (!user) {
            return ctx.redirect(303, '/login');
        }
        const { code } = ctx.request.body;
        const secret = ctx.session.totpSecret;
        const validCode = otplib_1.authenticator.check(code, secret);
        if (!validCode) {
            return ctx.redirect(303, '/register/mfa/totp?error=Invalid+token');
        }
        ctx.session.totpSecret = null;
        await (0, service_1.save)({
            user,
            secret
        });
        return ctx.redirect(303, '/login?msg=Registration+successful.+Please log in');
    }
}
exports.default = new TOTPRegisterController();
//# sourceMappingURL=register.js.map