"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const server_1 = require("@simplewebauthn/server");
const service_1 = require("../../../log/service");
const types_1 = require("../../../log/types");
const server_settings_1 = require("../../../server-settings");
const webauthnService = require("../service");
class WebAuthnLoginRequestController extends controller_1.default {
    async get(ctx) {
        const { user } = ctx.session.mfa || {};
        const authenticationOptions = (0, server_1.generateAuthenticationOptions)({
            timeout: 60000,
            allowCredentials: (await webauthnService.findDevicesByUser(user)).map(device => ({
                id: device.credentialID,
                type: 'public-key',
            })),
            /**
             * This optional value controls whether or not the authenticator needs be able to uniquely
             * identify the user interacting with it (via built-in PIN pad, fingerprint scanner, etc...)
             */
            userVerification: 'preferred',
        });
        ctx.session.webAuthnChallengeLogin = authenticationOptions.challenge;
        ctx.response.body = authenticationOptions;
    }
    async post(ctx) {
        const { user } = ctx.session.mfa || {};
        const body = ctx.request.body;
        const expectedChallenge = ctx.session.webAuthnChallengeLogin;
        ctx.session.webAuthnChallengeLogin = null;
        const authenticatorDevice = await webauthnService.findDeviceByUserAndId(user, body.id);
        let verification;
        try {
            verification = (0, server_1.verifyAuthenticationResponse)({
                credential: body,
                expectedChallenge,
                expectedOrigin: (0, server_settings_1.getSetting)('webauthn.expectedOrigin') || new URL(process.env.PUBLIC_URI).origin,
                expectedRPID: (0, server_settings_1.getSetting)('webauthn.relyingPartyId') || new URL(process.env.PUBLIC_URI).host,
                authenticator: {
                    credentialID: authenticatorDevice.credentialID,
                    counter: authenticatorDevice.counter,
                    credentialPublicKey: authenticatorDevice.publicKey,
                }
            });
        }
        catch (error) {
            (0, service_1.default)(types_1.EventType.totpFailed, ctx.ip(), user.id);
            ctx.status = 400;
            ctx.response.body = { error: error.message };
            return;
        }
        const { verified, authenticationInfo } = verification;
        if (verified) {
            authenticatorDevice.counter = authenticationInfo.newCounter;
            await webauthnService.save(authenticatorDevice);
        }
        ctx.session.mfa = null;
        ctx.session = {
            user: user,
        };
        (0, service_1.default)(types_1.EventType.loginSuccess, ctx);
        ctx.response.body = { verified };
    }
}
exports.default = new WebAuthnLoginRequestController();
//# sourceMappingURL=login.js.map