"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.recordToModel = exports.hasWebauthn = exports.findDeviceByUserAndId = exports.findDevicesByUser = exports.save = void 0;
const http_errors_1 = require("@curveball/http-errors");
const database_1 = require("../../database");
async function save(webAuthNDevice) {
    if (!isExistingDevice(webAuthNDevice)) {
        const newWebAuthnRecord = {
            user_id: webAuthNDevice.user.id,
            credential_id: webAuthNDevice.credentialID.toString('base64'),
            public_key: webAuthNDevice.publicKey.toString('base64'),
            counter: webAuthNDevice.counter,
            created: Math.floor(Date.now() / 1000),
        };
        const result = await (0, database_1.insertAndGetId)('user_webauthn', newWebAuthnRecord);
        return {
            id: result,
            ...webAuthNDevice
        };
    }
    else {
        const updateWebAuthnRecord = {
            credential_id: webAuthNDevice.credentialID.toString('base64'),
            public_key: webAuthNDevice.publicKey.toString('base64'),
            counter: webAuthNDevice.counter
        };
        await (0, database_1.default)('user_webauthn')
            .where('id', webAuthNDevice.id)
            .update(updateWebAuthnRecord);
        return webAuthNDevice;
    }
}
exports.save = save;
async function findDevicesByUser(user) {
    const result = await (0, database_1.query)('SELECT id, credential_id, public_key, counter FROM user_webauthn WHERE user_id = ?', [user.id]);
    return result.map((row) => recordToModel(row, user));
}
exports.findDevicesByUser = findDevicesByUser;
async function findDeviceByUserAndId(user, credentialId) {
    const result = await (0, database_1.query)('SELECT id, credential_id, public_key, counter FROM user_webauthn WHERE user_id = ? and credential_id = ?', [user.id, credentialId]);
    if (result.length !== 1) {
        throw new http_errors_1.NotFound('Device with id: ' + credentialId + ' not found');
    }
    return recordToModel(result[0], user);
}
exports.findDeviceByUserAndId = findDeviceByUserAndId;
async function hasWebauthn(user) {
    const result = await (0, database_1.query)('SELECT credential_id FROM user_webauthn WHERE user_id = ?', [user.id]);
    return result.length !== 0;
}
exports.hasWebauthn = hasWebauthn;
function recordToModel(userWebAuthn, user) {
    return {
        id: userWebAuthn.id,
        user: user,
        credentialID: Buffer.from(userWebAuthn.credential_id, 'base64'),
        publicKey: Buffer.from(userWebAuthn.public_key, 'base64'),
        counter: userWebAuthn.counter,
    };
}
exports.recordToModel = recordToModel;
function isExistingDevice(device) {
    return device.id !== undefined;
}
//# sourceMappingURL=service.js.map