"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const csv = require("../formats/csv");
const principalService = require("../../principal/service");
const oauth2Service = require("../service");
const oauth2ClientService = require("../../oauth2-client/service");
const privilegeService = require("../../privilege/service");
class UserActiveSessions extends controller_1.default {
    async get(ctx) {
        const user = await principalService.findByExternalId(ctx.params.id);
        if (ctx.auth.equals(user) && !await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('You can only use this API for yourself yourself, or if you have \'admin\' privileges');
        }
        if (!assertNotGroup(user)) {
            throw new http_errors_1.NotFound('This endpoint only exists for users and apps');
        }
        const tokens = await oauth2Service.getActiveTokens(user);
        const clients = new Map();
        for (const token of tokens) {
            clients.set(token.clientId, await oauth2ClientService.findById(token.clientId));
        }
        ctx.response.status = 200;
        ctx.response.type = 'text/csv';
        ctx.response.body = csv.activeSessions(tokens, clients);
    }
}
function assertNotGroup(input) {
    return ['user', 'app'].includes(input.type);
}
exports.default = new UserActiveSessions();
//# sourceMappingURL=active-sessions.js.map