"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPublicKey = exports.generateJWTAccessToken = void 0;
const crypto_1 = require("../crypto");
const server_settings_1 = require("../server-settings");
const crypto_2 = require("crypto");
const jose_1 = require("jose");
async function generateJWTAccessToken(user, client, expiry, scopes) {
    const origin = process.env.PUBLIC_URI;
    const jti = await (0, crypto_1.generateSecretToken)();
    const privateKey = getPrivateKey();
    const jwt = await new jose_1.SignJWT({
        scope: scopes.join(' '),
    })
        .setProtectedHeader({ alg: 'RS256' })
        .setIssuedAt()
        .setIssuer(origin)
        .setAudience(client.app.href)
        .setSubject(user.href)
        .setExpirationTime(Math.floor(Date.now() / 1000) + expiry)
        .setJti(jti)
        .sign(privateKey);
    return jwt;
}
exports.generateJWTAccessToken = generateJWTAccessToken;
let privateKey;
function getPrivateKey() {
    if (privateKey) {
        return privateKey;
    }
    privateKey = (0, crypto_2.createPrivateKey)(getRawPrivateKey());
    return privateKey;
}
let publicKey;
function getPublicKey() {
    if (publicKey)
        return publicKey;
    publicKey = (0, crypto_2.createPublicKey)({
        key: getRawPrivateKey()
    });
    return publicKey;
}
exports.getPublicKey = getPublicKey;
function getRawPrivateKey() {
    const key = (0, server_settings_1.getSetting)('jwt.privateKey');
    if (!key) {
        throw new Error('The JWT_PRIVATE_KEY environment variable must be set, and must be a RSA private key file (typically a .pem file)');
    }
    // Some environment variable systems will convert the newline to a literal '\n'.
    // this is a safe operation, because the file should not contain any literal
    // backslashes.
    return Buffer.from(key.replace(/\\n/gm, '\n'));
}
//# sourceMappingURL=jwt.js.map