"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateToken = exports.createToken = void 0;
const database_1 = require("../database");
const principalService = require("../principal/service");
const http_errors_1 = require("@curveball/http-errors");
const crypto_1 = require("../crypto");
/**
 * 2 hour token timeout
 */
const tokenTTL = 7200;
/**
 * This function will create a unique token then store it in the database
 */
async function createToken(user) {
    const token = await (0, crypto_1.generateSecretToken)();
    const query = 'INSERT INTO reset_password_token SET user_id = ?, token = ?, expires_at = ?, created_at = ?';
    await database_1.default.raw(query, [
        user.id,
        token,
        Math.floor(Date.now() / 1000) + tokenTTL,
        Math.floor(Date.now() / 1000),
    ]);
    return {
        token,
        expires: new Date(Date.now() + tokenTTL * 1000),
        ttl: tokenTTL,
    };
}
exports.createToken = createToken;
/**
 * Checks if a 'password reset token' is valid, and returns the associated user.
 * This function only works once for every token.
 * After calling this function, the token automatically gets deleted.
 */
async function validateToken(token) {
    const query = 'SELECT token, user_id FROM reset_password_token WHERE token = ? AND expires_at > ?';
    const result = await database_1.default.raw(query, [token, Math.floor(Date.now() / 1000)]);
    if (result[0].length !== 1) {
        throw new http_errors_1.BadRequest('Failed to validate token');
    }
    else {
        await database_1.default.raw('DELETE FROM reset_password_token WHERE token = ?', [token]);
        return principalService.findById(result[0][0].user_id);
    }
}
exports.validateToken = validateToken;
//# sourceMappingURL=service.js.map