import { Principal, NewPrincipal, PrincipalType, User, Group, App, PrincipalStats, BasePrincipal } from './types';
import { Principal as PrincipalRecord } from 'knex/types/tables';
export declare class InactivePrincipal extends Error {
}
export declare const fieldNames: Array<keyof PrincipalRecord>;
export declare function findAll(type: 'user'): Promise<User[]>;
export declare function findAll(type: 'group'): Promise<Group[]>;
export declare function findAll(type: 'app'): Promise<App[]>;
export declare function findAll(): Promise<Principal[]>;
export declare function getPrincipalStats(): Promise<PrincipalStats>;
export declare function findById(id: number, type: 'user'): Promise<User>;
export declare function findById(id: number, type: 'group'): Promise<Group>;
export declare function findById(id: number, type: 'app'): Promise<App>;
export declare function findById(id: number): Promise<Principal>;
export declare function findByExternalId(externalId: string, type: 'user'): Promise<User>;
export declare function findByExternalId(externalId: string, type: 'group'): Promise<Group>;
export declare function findByExternalId(externalId: string, type: 'app'): Promise<App>;
export declare function findByExternalId(externalId: string): Promise<Principal>;
/**
 * Returns true if more than 1 principal exists in the system.
 *
 * If there are 0 principals, this puts a12nserver in setup mode, which allows a
 * person to create the first user in the system, automatically activate it
 * and make them an admin.
 */
export declare function hasPrincipals(): Promise<boolean>;
export declare function findByIdentity(identity: string): Promise<Principal>;
/**
 * Finds a principal by its href'.
 *
 * This can be a string like /user/1, or a full url.
 * It can also be the uri listed in the 'identity' field.
 */
export declare function findByHref(href: string): Promise<Principal>;
export declare function save<T extends PrincipalType>(principal: BasePrincipal<T> | NewPrincipal<T>): Promise<BasePrincipal<T>>;
export declare function recordToModel(user: PrincipalRecord): Principal;
export declare function isIdentityValid(identity: string): boolean;
export declare function getPathName(href: string): string;
