"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const service_1 = require("../../log/service");
const types_1 = require("../../log/types");
const principalService = require("../../principal/service");
const html_1 = require("../formats/html");
const service_2 = require("../service");
/**
 * This controller is used for requesting change password when the user forgot the password.
 *
 * In this flow a user first submits the email address and if the email exists in the database,
 * server will send an email.
 */
class ResetPasswordRequestController extends controller_1.default {
    async get(ctx) {
        ctx.response.type = 'text/html';
        ctx.response.body = (0, html_1.resetPasswordRequestForm)(ctx.query.msg, ctx.query.error);
    }
    async post(ctx) {
        let user;
        try {
            user = await principalService.findByIdentity('mailto:' + ctx.request.body.emailAddress);
        }
        catch (err) {
            if (err instanceof http_errors_1.NotFound) {
                ctx.redirect(303, '/reset-password?error=Account+not+found.+Please+try+again');
                return;
            }
            else {
                throw err;
            }
        }
        if (!user.active) {
            ctx.redirect(303, '/reset-password?error=User+account+is+inactive,+please+contact+administrator.');
            return;
        }
        if (user.type !== 'user') {
            throw new http_errors_1.BadRequest('This endpoint can only be called for principals of type \'user\'.');
        }
        await (0, service_2.sendResetPasswordEmail)(user);
        await (0, service_1.default)(types_1.EventType.resetPasswordRequest, ctx.ip(), user.id);
        ctx.redirect(303, '/reset-password?msg=Password+reset+request+submitted.+Please+check+your+email+for+further+instructions.');
    }
}
exports.default = new ResetPasswordRequestController();
//# sourceMappingURL=request.js.map