"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const service_1 = require("../../log/service");
const types_1 = require("../../log/types");
const UserService = require("../../user/service");
const redirect_1 = require("../formats/redirect");
class ResetPasswordController extends controller_1.default {
    /**
     * If passwords provided didn't match for new and confirm passwords, it will
     * render this reset password form.
     */
    async get(ctx) {
        if (!ctx.session.resetPasswordUser) {
            throw new http_errors_1.Forbidden('You can only use this endpoint after you went through the \'forgot password\' flow');
        }
        ctx.response.type = 'text/html';
        ctx.response.body = (0, redirect_1.resetPasswordForm)(ctx.query.msg, ctx.query.error);
    }
    /**
     * This request checks if provided 2 passwords, new password and confirm password, is identical
     * and updates database with the new password.
     */
    async post(ctx) {
        if (!ctx.session.resetPasswordUser) {
            throw new http_errors_1.Forbidden('You can only use this endpoint after you went through the \'forgot password\' flow');
        }
        const user = ctx.session.resetPasswordUser;
        const resetNewPassword = ctx.request.body.newPassword;
        const confirmNewPassword = ctx.request.body.confirmNewPassword;
        if (resetNewPassword !== confirmNewPassword) {
            ctx.status = 303;
            ctx.response.headers.set('Location', '/reset-password/change-password?error=New+password+mismatch.+Please+try+again');
            return;
        }
        await UserService.updatePassword(user, resetNewPassword);
        delete ctx.session.resetPasswordUser;
        (0, service_1.default)(types_1.EventType.resetPasswordSuccess, ctx.ip(), user.id);
        ctx.status = 303;
        ctx.response.headers.set('Location', '/login?msg=Your+new+password+has+been+saved');
    }
}
exports.default = new ResetPasswordController();
//# sourceMappingURL=reset-password.js.map