"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sendResetPasswordEmail = void 0;
const nodemailer = require("nodemailer");
const templates_1 = require("../templates");
const service_1 = require("../one-time-token/service");
const server_settings_1 = require("../server-settings");
/**
 * This function is for sending reset password email with validated token
 *
 * This flow, it will first check if email and URL environment variable has been set.
 *
 * Renders an email with provided from, to, subject, html template.
 */
async function sendResetPasswordEmail(user) {
    const smtpEmailFrom = (0, server_settings_1.requireSetting)('smtp.emailFrom');
    const smtpUrl = (0, server_settings_1.requireSetting)('smtp.url');
    const transporter = nodemailer.createTransport(smtpUrl);
    const token = await (0, service_1.createToken)(user);
    const emailTemplate = (0, templates_1.render)('emails/reset-password-email', {
        name: user.nickname,
        url: process.env.PUBLIC_URI + 'reset-password/token/' + token.token,
        expiryHours: token.ttl / 60 / 60
    }, false);
    // send mail with defined transport object
    const info = await transporter.sendMail({
        from: smtpEmailFrom,
        to: user.identity.substring(7),
        subject: 'Password reset request',
        html: emailTemplate
    });
    nodemailer.getTestMessageUrl(info);
}
exports.sendResetPasswordEmail = sendResetPasswordEmail;
//# sourceMappingURL=service.js.map