export declare type Settings = {
    'login.defaultRedirect': string;
    'registration.enabled': boolean;
    'registration.mfa.enabled': boolean;
    'cors.allowOrigin': string[] | null;
    'db.driver': 'mysql2' | 'pg' | 'sqlite3' | 'mysql';
    'db.host': string | null;
    'db.user': string;
    'db.password': string | null;
    'db.database': string;
    'db.filename': string;
    'db.mysql_instance_connection_name': string | null;
    'redis.uri': null | string;
    'smtp.url': null | string;
    'smtp.emailFrom': null | string;
    'oauth2.code.expiry': number;
    'oauth2.accessToken.expiry': number;
    'oauth2.refreshToken.expiry': number;
    'jwt.privateKey': string | null;
    'totp': 'enabled' | 'required' | 'disabled';
    'totp.serviceName': string;
    'webauthn': 'enabled' | 'disabled' | 'required';
    'webauthn.expectedOrigin': string | null;
    'webauthn.relyingPartyId': string | null;
    'webauthn.serviceName': string;
    'logo_url': string;
};
export declare type SettingsRules = {
    [Setting in keyof Settings]: {
        description: string;
        env?: string;
        fromDb: boolean;
        isSecret?: boolean;
        default: Settings[Setting];
    };
};
export declare const settingsRules: SettingsRules;
/**
 * Retrieves the value of a single setting, by name
 */
export declare function getSetting<T extends keyof Settings>(setting: T): Settings[T];
/**
 * Retrieves the value of a single setting, by name.
 *
 * If the setting was not provided (null) this function will throw an exception.
 */
export declare function requireSetting<T extends keyof Settings>(setting: T): Settings[T];
export declare function getSettings(): Settings;
/**
 * Loads or reloads settings from the database.
 */
export declare function load(): Promise<void>;
