"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadTemplate = exports.getTemplate = exports.render = void 0;
const fs = require("fs");
const handlebars = require("handlebars");
const server_settings_1 = require("./server-settings");
const templates = new Map();
function render(name, params, renderLayoutWrapper = true) {
    const layoutTemplate = getTemplate('layout');
    const pageTemplate = getTemplate(name);
    const newParams = {};
    Object.assign(newParams, params, {
        appName: 'Auth API',
        logoUrl: (0, server_settings_1.getSetting)('logo_url')
    });
    if (renderLayoutWrapper) {
        return layoutTemplate({
            ...newParams,
            body: pageTemplate(newParams)
        });
    }
    else {
        return pageTemplate(newParams);
    }
}
exports.render = render;
function getTemplate(name) {
    // Don't cache in dev
    if (process.env.NODE_ENV !== 'production') {
        return loadTemplate(name);
    }
    if (!templates.has(name)) {
        templates.set(name, loadTemplate(name));
    }
    return templates.get(name);
}
exports.getTemplate = getTemplate;
function loadTemplate(name) {
    const template = handlebars.compile(fs.readFileSync(__dirname + '/../templates/' + name + '.hbs', 'utf-8'));
    return template;
}
exports.loadTemplate = loadTemplate;
//# sourceMappingURL=templates.js.map