"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const privilegeService = require("../../privilege/service");
const hal = require("../formats/hal");
const http_errors_1 = require("@curveball/http-errors");
const principalService = require("../../principal/service");
class UserEditController extends controller_1.default {
    async get(ctx) {
        const user = await principalService.findByExternalId(ctx.params.id);
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege use this endpoint');
        }
        ctx.response.body = hal.edit(user);
    }
    async post(ctx) {
        const userBody = ctx.request.body;
        const userOld = await principalService.findByExternalId(ctx.params.id);
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege use this endpoint');
        }
        delete userBody['csrf-token'];
        const userUpdated = Object.assign({}, userOld, {
            ...userBody,
            active: userBody.active === 'true' ? true : false,
        });
        const user = await principalService.save(userUpdated);
        ctx.redirect(303, `/user/${user.id}`);
    }
}
exports.default = new UserEditController();
//# sourceMappingURL=edit.js.map