"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const privilegeService = require("../../privilege/service");
const principalService = require("../../principal/service");
const html_1 = require("../formats/html");
class CreateUserController extends controller_1.default {
    async get(ctx) {
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege can create new users');
        }
        ctx.response.type = 'text/html';
        ctx.response.body = (0, html_1.createUserForm)(ctx.query.msg, ctx.query.error);
    }
    async post(ctx) {
        ctx.request.validate('https://curveballjs.org/schemas/a12nserver/user-new-form.json');
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege can create new users');
        }
        const identity = ctx.request.body.identity;
        const nickname = ctx.request.body.nickname;
        if (!principalService.isIdentityValid(identity)) {
            throw new http_errors_1.UnprocessableEntity('Identity must be a valid URI');
        }
        try {
            await principalService.findByIdentity(ctx.request.body.identity);
            ctx.status = 303;
            ctx.response.headers.set('Location', '/user/new?error=User+already+exists');
            return;
        }
        catch (err) {
            if (!(err instanceof http_errors_1.NotFound)) {
                throw err;
            }
        }
        const newUser = await principalService.save({
            identity: identity,
            nickname: nickname,
            createdAt: new Date(),
            modifiedAt: new Date(),
            type: 'user',
            active: 'active' in ctx.request.body
        });
        ctx.response.status = 303;
        ctx.response.headers.set('Location', '/user/' + newUser.id);
    }
}
exports.default = new CreateUserController();
//# sourceMappingURL=new.js.map