"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const privilegeService = require("../../privilege/service");
const hal = require("../formats/hal");
const principalService = require("../../principal/service");
class UserEditPrivilegesController extends controller_1.default {
    async get(ctx) {
        const user = await principalService.findByExternalId(ctx.params.id);
        const privileges = await privilegeService.getImmediatePrivilegesForPrincipal(user);
        await privilegeService.hasPrivilege(ctx, 'admin');
        ctx.response.body = hal.editPrivileges(user, privileges);
    }
    async post(ctx) {
        const { policyBody } = ctx.request.body;
        const user = await principalService.findByExternalId(ctx.params.id);
        await privilegeService.hasPrivilege(ctx, 'admin');
        try {
            const policy = JSON.parse(policyBody);
            await privilegeService.replacePrivilegeForUser(user, policy);
        }
        catch (err) {
            throw new http_errors_1.BadRequest(err);
        }
        ctx.redirect(303, `/user/${user.id}`);
    }
}
exports.default = new UserEditPrivilegesController();
//# sourceMappingURL=privileges.js.map